Reporting Issues and Contributing Code
======================================

Reporting Issues
----------------

If you have found a bug in EclipsingBinaries, please report it by creating a new issue on the `EclipsingBinaries issue tracker <https://github.com/kjkoeller/EclipsingBinaries/issues>`_.

Please include an example that demonstrates the issue and will allow for developers to reporoduce and fir the problem. Please also provide information regarding your operating system and Python version.

Contributing Code
-----------------

We accept contributions at all levels, spanning from fixing a simple typo to developing major features. We welcome contributors who will abide by the `EclipsingBinaries Code of Conduct <https://github.com/kjkoeller/EclipsingBinaries/blob/main/CODE_OF_CONDUCT.md>`_.

EclipsingBinaries uses multiple workflows and coding guidelines to make sure that any code contributed will run across multiple Python versions and multiple operating systems.
